@@ -1,5 +1,6 @@
 import logging
 import os
+import re
 import sys
 
 from cliff.app import App
@@ -12,11 +13,11 @@ os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'enough.settings')
 
 class EnoughApp(App):
 
-    def __init__(self):
-        super(EnoughApp, self).__init__(
+    def __init__(self, modules):
+        super().__init__(
             description='enough',
             version=__version__,
-            command_manager=CommandManager('enough.cli'),
+            command_manager=CommandManager(modules),
             deferred_help=True,
             )
 
@@ -41,9 +42,39 @@ class EnoughApp(App):
         parser.add_argument('--domain', default='enough.community', help='Enough domain name')
         return parser
 
+    @staticmethod
+    def remap_dot_enough(argv):
+        home = os.path.expanduser('~/.enough')
+
+        def remap(s):
+            s = re.sub(r'^/\S+/.enough', home, s)
+            s = re.sub(r'=/\S+/.enough', f'={home}', s)
+            return s
+        return [remap(a) for a in argv]
+
+    @staticmethod
+    def is_root():
+        return os.geteuid() == 0
+
+    @staticmethod
+    def preserve_ownership():
+        uid = os.geteuid()
+        home = os.path.expanduser('~/.enough')
+        if not uid == 0 or not os.path.exists(home):
+            return False
+        home_uid = os.stat(home).st_uid
+        if uid != home_uid:
+            os.system(f'chown -R {home_uid} {home}')
+        return True
+
+    def run(self, argv):
+        r = super().run(EnoughApp.remap_dot_enough(argv))
+        EnoughApp.preserve_ownership()
+        return r
+
 
 def main(argv=sys.argv[1:]):
-    myapp = EnoughApp()
+    myapp = EnoughApp('enough.cli')
     return myapp.run(argv)
 
 
